@@ -1,8 +1,13 @@
 /*
+ * $LynxId: userdefs.h,v 1.246 2009/05/28 21:37:22 tom Exp $
+ *
  * Lynx - Hypertext navigation system
  *
  *   (c) Copyright 1992, 1993, 1994 University of Kansas
  *	 1995, 1996: GNU General Public License
+ *
+ *   Copyrights 1996-2007 Lynx Developers Group
+ *   Note: GNU General Public License is not a copyright.
  */
 
 /*******************************************************************
@@ -242,7 +247,7 @@
  * Things you must change  -  non-VMS specific
  *  Section 1b).
  */
-#else     /* non-VMS: UNIX etc. */
+#else /* non-VMS: UNIX etc. */
 
 /**************************
  * NOTE: This variable is set by the configure script; editing changes will
@@ -289,6 +294,10 @@
 #endif /* LYNX_CFG_FILE */
 #endif /* HAVE_CONFIG_H */
 
+#ifndef MIME_LIBDIR
+#define MIME_LIBDIR "/etc/"
+#endif
+
 /**************************
  * The EXTENSION_MAP file allows you to map file suffixes to
  * mime types.
@@ -296,8 +305,8 @@
  * Mappings in these global and personal files override any SUFFIX
  * definitions in lynx.cfg and built-in defaults from src/HTInit.c.
  */
-#define GLOBAL_EXTENSION_MAP "/usr/local/lib/mosaic/mime.types"
-#define PERSONAL_EXTENSION_MAP ".mime.types"
+#define GLOBAL_EXTENSION_MAP MIME_LIBDIR "mime.types"
+#define PERSONAL_EXTENSION_MAP "~/.mime.types"
 
 /**************************
  * The MAILCAP file allows you to map file MIME types to
@@ -306,8 +315,8 @@
  * Mappings in these global and personal files override any VIEWER
  * definitions in lynx.cfg and built-in defaults from src/HTInit.c.
  */
-#define GLOBAL_MAILCAP "/usr/local/lib/mosaic/mailcap"
-#define PERSONAL_MAILCAP ".mailcap"
+#define GLOBAL_MAILCAP MIME_LIBDIR "mailcap"
+#define PERSONAL_MAILCAP "~/.mailcap"
 
 /**************************
  * XLOADIMAGE_COMMAND will be used as a default in src/HTInit.c for
@@ -405,6 +414,12 @@
 #define LIST_FORMAT "    %p %4l %-8.8o %-8.8g %7s %-12.12d %a"
 #endif
 
+/*
+ * FTP_FORMAT uses the same codes as LIST_FORMAT, but applies to files shown
+ * in an ftp listing.
+ */
+#define FTP_FORMAT "%d  %-16.16t %a  %K"
+
 /*
  *  If NO_FORCED_CORE_DUMP is set to TRUE, Lynx will not force
  *  core dumps via abort() calls on fatal errors or assert()
@@ -471,10 +486,12 @@
  *   for this distribution (use SHELL syntax including the device
  *   on VMS systems).
  * The default HELPFILE is:
- * http://www.subir.com/lynx/lynx_help/lynx_help_main.html
+ * http://lynx.isc.org/release/lynx2-8-6/lynx_help/lynx_help_main.html
  *   This should be changed here or in lynx.cfg to the local path.
+ * The definition here can be overridden at run time by defining a
+ * "LYNX_HELPFILE" environment variable.
  */
-#define HELPFILE "http://www.subir.com/lynx/lynx_help/lynx_help_main.html"
+#define HELPFILE "http://lynx.isc.org/release/lynx2-8-6/lynx_help/lynx_help_main.html"
 /* #define HELPFILE "file://localhost/PATH_TO/lynx_help/lynx_help_main.html" */
 
 /*****************************
@@ -875,6 +892,12 @@
  */
 #define SET_COOKIES TRUE
 
+/********************************
+ * If SEND_USERAGENT is set FALSE, Lynx will not send a user-agent string.
+ * You can override this in the 'O'ptions menu.
+ */
+#define SEND_USERAGENT TRUE
+
 /*******************************
  * If ACCEPT_ALL_COOKIES is set TRUE, and SET_COOKIES is TRUE, Lynx will
  * accept all cookies.
@@ -884,7 +907,6 @@
  */
 #define ACCEPT_ALL_COOKIES FALSE
 
-
 /****************************************************************
  *   Section 2.   Things that you probably want to change or review
  *
@@ -970,7 +992,7 @@
 #define BOXHORI '-'
 /* #define BOXHORI 0 */
 #endif /* DOSPATH */
-#endif	/* !HAVE_CONFIG_H */
+#endif /* !HAVE_CONFIG_H */
 
 /******************************
  * LY_UMLAUT controls the 7-bit expansion of characters with dieresis or
@@ -1146,7 +1168,7 @@
  *
  *  NOTE: This can generate A LOT of mail, be warned.
  */
-#define MAIL_SYSTEM_ERROR_LOGGING   FALSE  /*mail a message for every error?*/
+#define MAIL_SYSTEM_ERROR_LOGGING   FALSE	/*mail a message for every error? */
 
 /*********************************
  *  If a document cannot be accessed, and MAIL_SYSTEM_ERROR_LOGGING
@@ -1156,7 +1178,7 @@
  *
  *  NOTE: This can generate A REAL LOT of mail, be warned!!!
  */
-/* #define ALERTMAIL "webmaster@localhost" */ /*error recipient if no owner*/
+/* #define ALERTMAIL "webmaster@localhost" *//*error recipient if no owner */
 
 /*********************************
  * If CHECKMAIL is set to TRUE, the user will be informed (via a status line
@@ -1182,8 +1204,8 @@
  * Vi or Emacs movement keys.  These are defaults,
  * which can be changed in lynx.cfg , the Options Menu or .lynxrc .
  */
-#define VI_KEYS_ALWAYS_ON	FALSE /* familiar h j k l */
-#define EMACS_KEYS_ALWAYS_ON	FALSE /* familiar ^N ^P ^F ^B */
+#define VI_KEYS_ALWAYS_ON	FALSE	/* familiar h j k l */
+#define EMACS_KEYS_ALWAYS_ON	FALSE	/* familiar ^N ^P ^F ^B */
 
 /*********************************
  * DEFAULT_KEYPAD_MODE may be set to NUMBERS_AS_ARROWS
@@ -1202,7 +1224,7 @@
  * The default search.
  * This is a default that can be overridden in lynx.cfg or by the user!
  */
-#define CASE_SENSITIVE_ALWAYS_ON    FALSE /* case sensitive user search */
+#define CASE_SENSITIVE_ALWAYS_ON    FALSE	/* case sensitive user search */
 
 /********************************
  * If NO_DOT_FILES is set TRUE here or in lynx.cfg, the user will not be
@@ -1216,7 +1238,7 @@
  * If it is FALSE at startup of Lynx, the user can regulate it via the
  * 'o'ptions menu, and may save the preference in the RC file.
  */
-#define NO_DOT_FILES    TRUE  /* disallow access to dot files */
+#define NO_DOT_FILES    TRUE	/* disallow access to dot files */
 
 /********************************
  * If MAKE_LINKS_FOR_ALL_IMAGES is TRUE, all images will be given links
@@ -1231,7 +1253,7 @@
  *
  * The default also can be toggled via an "-image_links" command line switch.
  */
-#define MAKE_LINKS_FOR_ALL_IMAGES	FALSE /* inlines cast to links */
+#define MAKE_LINKS_FOR_ALL_IMAGES	FALSE	/* inlines cast to links */
 
 /********************************
  * If MAKE_PSEUDO_ALTS_FOR_INLINES is FALSE, inline images which do not
@@ -1247,7 +1269,7 @@
  * The default also can be toggled via a "-pseudo_inlines" command line
  * switch.
  */
-#define MAKE_PSEUDO_ALTS_FOR_INLINES	TRUE /* Use "[INLINE]" pseudo-ALTs */
+#define MAKE_PSEUDO_ALTS_FOR_INLINES	TRUE	/* Use "[INLINE]" pseudo-ALTs */
 
 /********************************
  * If SUBSTITUTE_UNDERSCORES is TRUE, the _underline_ format will be used
@@ -1256,7 +1278,7 @@
  * The default defined here can be changed in lynx.cfg, and the user can
  * toggle the default via a "-underscore" command line switch.
  */
-#define SUBSTITUTE_UNDERSCORES	FALSE /* Use _underline_ format in dumps */
+#define SUBSTITUTE_UNDERSCORES	FALSE	/* Use _underline_ format in dumps */
 
 /********************************
  * If QUIT_DEFAULT_YES is defined as TRUE then when the QUIT command
@@ -1335,7 +1357,6 @@
 #include <LYMessages_en.h>
 #endif /* !LYMESSAGES_EN_H */
 
-
 /****************************************************************
  * DEFAULT_VISITED_LINKS may be set to one or more of
  *					VISITED_LINKS_AS_FIRST_V
@@ -1349,6 +1370,51 @@
  */
 #define DEFAULT_VISITED_LINKS (VISITED_LINKS_AS_LATEST | VISITED_LINKS_REVERSE)
 
+/****************************************************************
+ * If USE_CACHEJAR is set to TRUE the user will be able to view,
+ * access and delete cached documents in current lynx session.
+ */
+#ifndef USE_CACHEJAR
+/* #define USE_CACHEJAR TRUE */
+#endif
+
+/****************************************************************
+ * If USE_SESSIONS is set to TRUE the user will be able to save,
+ * resume and in general manipulate with lynx sessions.
+ */
+#ifndef USE_SESSIONS
+/* #define USE_SESSIONS TRUE */
+#endif
+
+#define MAX_SESSIONS	10000
+
+/*
+ * If USE_SESSIONS is TRUE you may tune it fine how it will work:
+ */
+#define GOTOURL_IN_SESSION	/* Allow to save goto url */
+#define GOTOURL_OUT_SESSION	/* Allow to restore goto url */
+#define HISTORY_IN_SESSION	/* Allow to save history */
+#define HISTORY_OUT_SESSION	/* Allow to restore history */
+#define SEARCH_IN_SESSION	/* Allow to save search string */
+#define SEARCH_OUT_SESSION	/* Allow to restore search string */
+#define VLINK_IN_SESSION	/* Allow to save visited link */
+#define VLINK_OUT_SESSION	/* Allow to restore visited link */
+
+/****************************************************************
+ * The STATUSBUFSIZE defines how many entries will be stored in
+ * cyclic buffer of statusline messages. This is specially useful
+ * for users who use lynx on a terminal with more than 40 lines.
+ */
+/* #define STATUSBUFSIZE 90 */
+
+/****************************************************************
+ * If USE_PROGRESSBAR is TRUE the user will be able to set
+ * download progress as odometer(thermometer) display, ie:
+ *
+ * 80% IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII
+ *
+ */
+/* #define USE_PROGRESSBAR TRUE */
 
 /****************************************************************
  *   Section 3.   Things that you should not change until you
@@ -1360,16 +1426,23 @@
  * the version definition with the Project Version on checkout.  Just
  * ignore it. - kw */
 /* $Format: "#define LYNX_VERSION \"$ProjectVersion$\""$ */
-#define LYNX_VERSION "2.8.5rel.5"
+#define LYNX_VERSION "2.8.7rel.1"
 #define LYNX_WWW_HOME "http://lynx.isc.org/"
 #define LYNX_WWW_DIST "http://lynx.isc.org/current/"
 /* $Format: "#define LYNX_DATE \"$ProjectDate$\""$ */
-#define LYNX_DATE "Sat, 29 Oct 2005 12:33:45 -0700"
+#define LYNX_DATE "Sun, 05 Jul 2009 16:52:33 -0700"
 #define LYNX_DATE_OFF 5		/* truncate the automatically-generated date */
 #define LYNX_DATE_LEN 11	/* truncate the automatically-generated date */
 
+#ifdef UNICODE
+#define W32_STRING(s) L##s
+#else
+#define W32_STRING(s) s
+#endif
+
+#define LYNX_SUBKEY W32_STRING("Software\\Lynx")
+
 #define LINESIZE 1024		/* max length of line to read from file */
-#define MAXHIST  1024		/* max links we remember in history */
 #define MAXLINKS 1024		/* max links on one screen */
 
 #ifndef SEARCH_GOAL_LINE
@@ -1377,8 +1450,10 @@
 #endif
 
 #define MAXCHARSETS 60		/* max character sets supported */
-#define TRST_MAXROWSPAN 10000	/* max rowspan accepted by TRST code */
-#define TRST_MAXCOLSPAN 1000	/* max colspan and COL/COLGROUP span accepted */
+#define TRST_MAXROWSPAN 200	/* max rowspan accepted by TRST code */
+#define TRST_MAXCOLSPAN 200	/* max colspan and COL/COLGROUP span accepted */
+#define MAX_TABLE_ROWS  200	/* max rows for tables */
+#define MAX_TABLE_COLS  200	/* max cols for tables */
 #define SAVE_TIME_NOT_SPACE	/* minimize number of some malloc calls */
 
 /* Win32 may support more, but old win16 helper apps may not. */
@@ -1392,6 +1467,30 @@
 #define HTML_SUFFIX ".html"
 #endif
 
+#ifndef FNAME_LYNXRC
+#ifdef FNAMES_8_3
+#define FNAME_LYNXRC "lynx.rc"
+#else
+#define FNAME_LYNXRC ".lynxrc"
+#endif /* FNAMES_8_3 */
+#endif
+
+#ifndef FNAME_LYNX_COOKIES
+#ifdef FNAMES_8_3
+#define FNAME_LYNX_COOKIES "cookies"
+#else
+#define FNAME_LYNX_COOKIES ".lynx_cookies"
+#endif /* FNAMES_8_3 */
+#endif
+
+#ifndef FNAME_LYNX_TRACE
+#ifdef FNAMES_8_3
+#define FNAME_LYNX_TRACE "LY-TRACE.LOG"
+#else
+#define FNAME_LYNX_TRACE "Lynx.trace"
+#endif /* FNAMES_8_3 */
+#endif
+
 #define BIN_SUFFIX  ".bin"
 #define TEXT_SUFFIX ".txt"
 
@@ -1485,7 +1584,7 @@
  */
 #endif /* HAVE_CONFIG_H */
 
-#else	/* Unix */
+#else /* Unix */
 	/* Standard locations are defined via the configure script.  When
 	 * helper applications are in your home directory or other nonstandard
 	 * locations, you probably will have to preset the path to them with
@@ -1494,13 +1593,12 @@
 #endif /* DOSPATH */
 #endif /* VMS */
 
-
-/***************************** 
+/*****************************
  * I have not ported multibyte support for EBCDIC.  In fact, some multibyte
  * code in LYLowerCase() crashes on EBCDIC strings.  -- gil
  */
 #if       ! defined(NOT_ASCII)
-/***************************** 
+/*****************************
  * SUPPORT_MULTIBYTE_EDIT provides better support of CJK characters to
  * Lynx's Line Editor.  JIS X0201 Kana is partially supported.  The
  * reason why I didn't support it fully is I think supporting it is not
@@ -1509,7 +1607,7 @@
 #define SUPPORT_MULTIBYTE_EDIT
 #endif /* ! defined(NOT_ASCII) */
 
-/***************************** 
+/*****************************
  * SUPPORT_CHDIR provides CD command (bound to 'C' by default).  It allows
  * changing directory to arbitrary location (if OS allows them).  If dired is
  * enabled, user will be able to visit any directory and view any file allowed
@@ -1517,42 +1615,47 @@
  */
 #define SUPPORT_CHDIR
 
-/***************************** 
+/*****************************
  * MARK_HIDDEN_LINKS controls whether hidden links are shown with the title
  * set by the HIDDEN_LINK_MARKER string in lynx.cfg
  */
 #define MARK_HIDDEN_LINKS
 
 /*****************************
- * USE_TH_JP_AUTO_DETECT, CONV_JISX0201KANA_JISX0208KANA,  
- * and KANJI_CODE_OVERRIDE are the macros for Japanese. - TH 
- */ 
-/***************************** 
- * USE_TH_JP_AUTO_DETECT enables a new Japanese charset detection routine. 
- * With the old detection strategy, Lynx always thought a document was 
- * written in mixture of three kanji codes (JIS, EUC and SJIS).  The new 
- * strategy is for Lynx to first assume the document is written in one code 
- * or JIS + one other kanji code (JIS, EUC, SJIS, EUC+JIS and SJIS+JIS). 
- * The first assumption is usually correct, but if the assumption is wrong, 
- * Lynx falls back to the old assumption of the three kanji codes mixed. 
- */ 
-#define USE_TH_JP_AUTO_DETECT 
- 
-/***************************** 
- * If CONV_JISX0201KANA_JISX0208KANA is set, Lynx will convert 
- * JIS X0201 Kana to JIS X0208 Kana, i.e., convert half-width kana 
- * to full-width. 
- */ 
-#define CONV_JISX0201KANA_JISX0208KANA 
- 
-/***************************** 
- * Uncomment the following line to enable the kanji code override routine. 
- * The code can be changed by pressing ^L.  More precisely, this allows 
- * the user to override the assumption about the kanji code for the document 
- * which Lynx has made on the basis of a META tag and HTTP response. 
- */ 
-/*#define KANJI_CODE_OVERRIDE */ 
- 
+ * USE_TH_JP_AUTO_DETECT, CONV_JISX0201KANA_JISX0208KANA,
+ * and KANJI_CODE_OVERRIDE are the macros for Japanese. - TH
+ */
+/*****************************
+ * USE_TH_JP_AUTO_DETECT enables a new Japanese charset detection routine.
+ * With the old detection strategy, Lynx always thought a document was
+ * written in mixture of three kanji codes (JIS, EUC and SJIS).  The new
+ * strategy is for Lynx to first assume the document is written in one code
+ * or JIS + one other kanji code (JIS, EUC, SJIS, EUC+JIS and SJIS+JIS).
+ * The first assumption is usually correct, but if the assumption is wrong,
+ * Lynx falls back to the old assumption of the three kanji codes mixed.
+ */
+#define USE_TH_JP_AUTO_DETECT
+
+/*****************************
+ * If CONV_JISX0201KANA_JISX0208KANA is set, Lynx will convert
+ * JIS X0201 Kana to JIS X0208 Kana, i.e., convert half-width kana
+ * to full-width.
+ */
+#define CONV_JISX0201KANA_JISX0208KANA
+
+/*****************************
+ * Uncomment the following line to enable the kanji code override routine.
+ * The code can be changed by pressing ^L.  More precisely, this allows
+ * the user to override the assumption about the kanji code for the document
+ * which Lynx has made on the basis of a META tag and HTTP response.
+ */
+/*#define KANJI_CODE_OVERRIDE */
+
+/**************************
+ * SSL_CERT_FILE contains valid SSL CA certificates.  Set this to a string
+ * to provide a runtime default value.
+ */
+#define SSL_CERT_FILE NULL
 
 /****************************************************************
  *  Section 4.  Things you MUST check only if you plan to use Lynx
@@ -1625,7 +1728,7 @@
  * set to FALSE if you don't want users of your anonymous
  * account to be able to goto particular URLs.
  */
-#define CAN_ANONYMOUS_GOTO_BIBP		TRUE    /* BIBP maps to HTTP */
+#define CAN_ANONYMOUS_GOTO_BIBP		TRUE	/* BIBP maps to HTTP */
 #define CAN_ANONYMOUS_GOTO_CSO		FALSE
 #define CAN_ANONYMOUS_GOTO_FILE		FALSE
 #define CAN_ANONYMOUS_GOTO_FINGER	TRUE
